Export Package VRC : bcB61Ma ca02
Update compared VRC:   B61Xa ca02
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : No
Library sources    : No
Creation Date      : 041306 00:08:46
Total file size    : 347727
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
S = Subscription Templates
b = Functions
A = Additional Files
h = Help Text Codes
----------------------
sbccor0201m000                                        B61Ma ca02 (not expired)
sbccor0202m000                                        B61Ma ca02 (not expired)
sbccor0205m000                                        B61Ma ca02 (not expired)
sbccor0213m000                                        B61Ma ca02 (not expired)
pbccor0001                                            B61Ma ca02 (without source) (not expired)
pbccor0200                                            B61Ma ca02 (without source) (not expired)
pbccor0201                                            B61Ma ca02 (without source) (not expired)
pbccor0202                                            B61Ma ca02 (without source) (not expired)
pbccor0203                                            B61Ma ca02 (without source) (not expired)
pbccor0204                                            B61Ma ca02 (without source) (not expired)
pbccor0205                                            B61Ma ca02 (without source) (not expired)
pbccor0207                                            B61Ma ca02 (without source) (not expired)
pbccor0210                                            B61Ma ca02 (without source) (not expired)
pbccor0211                                            B61Ma ca02 (without source) (not expired)
pbccor0212                                            B61Ma ca02 (without source) (not expired)
pbccor0213                                            B61Ma ca02 (without source) (not expired)
pbccor0216                                            B61Ma ca02 (without source) (not expired)
pbccortestgz                                          B61Ma ca02 (without source) (expired)
pbccorts220                                           B61Ma ca02 (without source) (not expired)
pbcttf1206                                            B61Ma ca02 (without source) (not expired)
pbcttfdll0003                                         B61Ma ca02 (without source) (not expired)
pbcttfdll0004                                         B61Ma ca02 (without source) (not expired)
pbcttfdll0006                                         B61Ma ca02 (without source) (not expired)
pbcttfdll0008                                         B61Ma ca02 (without source) (not expired)
pbcttt9200                                            B61Ma ca02 (without source) (not expired)
fbccor0201m000d2                                      B61Ma ca02 (not expired)
fbccor0202m000d2                                      B61Ma ca02 (not expired)
fbccor0205m000d2                                      B61Ma ca02 (not expired)
fbccor0213m000d2                                      B61Ma ca02 (not expired)
rbccor0201010002                                      B61Ma ca02 (not expired)
rbccor0202010002                                      B61Ma ca02 (not expired)
rbccor0205110002                                      B61Ma ca02 (not expired)
rbccor0213110002                                      B61Ma ca02 (not expired)
cbccor0001                                            B61Ma ca02 (not expired)
obccnv5272                                            B61Ma ca02
obccor0001                                            B61Ma ca02
obccor0200                                            B61Ma ca02
obccor0201                                            B61Ma ca02
obccor0202                                            B61Ma ca02
obccor0203                                            B61Ma ca02
obccor0204                                            B61Ma ca02
obccor0205                                            B61Ma ca02
obccor0207                                            B61Ma ca02
obccor0210                                            B61Ma ca02
obccor0211                                            B61Ma ca02
obccor0212                                            B61Ma ca02
obccor0213                                            B61Ma ca02
obccor0216                                            B61Ma ca02
obccortestgz                                          B61Ma ca02
obccorts220                                           B61Ma ca02
obcgct8189                                            B61Ma ca02
obcgct8289                                            B61Ma ca02
obcrun80501                                           B61Ma ca02
obcrun90502                                           B61Ma ca02
obcrunonpload                                         B61Ma ca02
obcttc0100                                            B61Ma ca02
obcttc0201                                            B61Ma ca02
obcttf0105                                            B61Ma ca02
obcttf0110                                            B61Ma ca02
obcttf0201                                            B61Ma ca02
obcttf0220                                            B61Ma ca02
obcttf1206                                            B61Ma ca02
obcttfdll0003                                         B61Ma ca02
obcttfdll0004                                         B61Ma ca02
obcttfdll0006                                         B61Ma ca02
obcttfdll0008                                         B61Ma ca02
obctti0201                                            B61Ma ca02
obcttt9200                                            B61Ma ca02
obccor0201010002                                      B61Ma ca02
obccor0202010002                                      B61Ma ca02
obccor0205110002                                      B61Ma ca02
obccor0213110002                                      B61Ma ca02
lbcbc.item.from     109                               B61Ma ca02 (not expired)
lbcbccor0201.01     131                               B61Ma ca02 (not expired)
lbcbccors0205.01    116                               B61Ma ca02 (not expired)
lbcbccors0205.02    216                               B61Ma ca02 (not expired)
lbcbccors0205.03    216                               B61Ma ca02 (not expired)
lbccor020101000001  140                               B61Ma ca02 (not expired)
lbccor020101000002  140                               B61Ma ca02 (not expired)
lbccor0201m000001   140                               B61Ma ca02 (not expired)
lbccor0202001       130                               B61Ma ca02 (not expired)
lbccor020201000001  130                               B61Ma ca02 (not expired)
lbccor020201000002  130                               B61Ma ca02 (not expired)
lbccor020201000003  130                               B61Ma ca02 (not expired)
lbccor020201000004  132                               B61Ma ca02 (not expired)
lbccor020201000005  132                               B61Ma ca02 (not expired)
lbccor020201000006  130                               B61Ma ca02 (not expired)
lbccor020201000007  151                               B61Ma ca02 (not expired)
lbccor0202m000001   130                               B61Ma ca02 (not expired)
lbccor020511000001  146                               B61Ma ca02 (not expired)
lbccor0205m000001   146                               B61Ma ca02 (not expired)
lbccor021311000001  143                               B61Ma ca02 (not expired)
lbccor0213m000001   162                               B61Ma ca02 (not expired)
lbccor0213m000002   143                               B61Ma ca02 (not expired)
lbcitem.to          107                               B61Ma ca02 (not expired)
lbcloca             108                               B61Ma ca02 (not expired)
lbclot              103                               B61Ma ca02 (not expired)
lbcsimulate         108                               B61Ma ca02 (not expired)
lbcstorage.data     112                               B61Ma ca02 (not expired)
lbctrans.date       211                               B61Ma ca02 (not expired)
lbcttf.aext         115                               B61Ma ca02 (not expired)
lbcttf.anbr         112                               B61Ma ca02 (not expired)
lbcttf.book         110                               B61Ma ca02 (not expired)
lbcttf.meth         119                               B61Ma ca02 (not expired)
Fbccor0201m000d2                                      B61Ma ca02
Fbccor0202m000d2                                      B61Ma ca02
Fbccor0205m000d2                                      B61Ma ca02
Fbccor0213m000d2                                      B61Ma ca02
